@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0601';
 
 use Moo;
 use Music::Chord::Note;
@@ -131,7 +131,6 @@ sub _generate_chord {
         }
     }
     elsif ( $self->format eq 'midinum' ) {
-        $octave ||= 4;
         @notes = map { Music::Note->new( $_ . $octave, 'ISO' )->format('midinum') } @notes;
     }
     elsif ( $self->format ne 'isobase' ) {
@@ -159,7 +158,7 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0600
+version 0.0601
 
 =head1 SYNOPSIS
 
@@ -200,6 +199,7 @@ version 0.0600
 
   $mc = Music::Cadence->new(
     key    => 'C',
+    octave => 4,
     format => 'midinum',
   );
 
@@ -237,8 +237,15 @@ Supported scales are:
 
 =head2 octave
 
-The octave to append to chord notes.  Default: C<0> meaning "do not
-append."
+The octave to either append to named chord notes (for C<midi> or
+C<isobase> format) or to determine the correct C<midinum> note number.
+
+Default: C<0>
+
+If the B<format> is C<midi> or C<isobase>, setting this to C<0> means
+"do not append."
+
+The C<midinum> range for this attribute is from C<-1> to C<10>.
 
 =head2 format
 
